﻿------------------------------
--      Are you local?    --
------------------------------

local boss = AceLibrary("Babble-Boss-2.2")["Gruul the Dragonkiller"]
local L = AceLibrary("AceLocale-2.2"):new("BigWigs"..boss)
local grasp
local slam
local growcount

----------------------------
--      Localization     --
----------------------------

L:RegisterTranslations("enUS", function() return {
	cmd = "Gruul",

	engage_cmd = "engage",
	engage_name = "Engage",
	engage_desc = "Warn when Grull is pulled",

	grow_cmd = "grow",
	grow_name = "Grow",
	grow_desc = "Warn when Grull grows",

	grasp_cmd = "grasp",
	grasp_name = "Grasp",
	grasp_desc = "Warn when Gruul casts Gronn Lord's Grasp",

	cavein_cmd = "cavein",
	cavein_name = "Cave In on You",
	cavein_desc = "Warn for a Cave In on You",

	engage_trigger = "Come.... and die.",
	engage_message = "Gruul Engaged!",

	grow_trigger = "%s grows in size!",
	grow_message = "Grows: (%d)",
	grow_warning = "Grow (%d) in ~5sec",
	grow_bar = "Grow (%d)",

	grasp_trigger1 = "afflicted by Ground Slam",
	grasp_trigger2 = "afflicted by Gronn Lord's Grasp",
	grasp_message1 = "Grasp Incoming!",
	grasp_message2 = "Grasp!",
	grasp_warning = "Grasp Soon!",

	cavein_trigger = "You are afflicted by Cave In.",
	cavein_message = "Cave In on YOU!",
} end)

L:RegisterTranslations("deDE", function() return {
	engage_name = "Pull Warnung",
	engage_desc = "Warnt, wenn Gruul gepulled wird",

	--grow_name = "Wachstum Warnung", --enUS changed
	--grow_desc = "Warnt, wenn Gruul w\195\164chst", --enUS changed

	grasp_name = "Griff Warnung",
	grasp_desc = "Warnt, wenn Gruul Griff des Gronnlords zaubert",

	cavein_name = "H\195\182hleneinst\195\188rz auf dich",
	cavein_desc = "Warnt bei H\195\182hleneinst\195\188rz auf dir",

	engage_trigger = "Kommt und sterbt.",
	engage_message = "Gruul gepullt!",

	grow_trigger = "%s wird gr\195\182\195\159er!",
	--grow_message = "Gruul w\195\164chst!", --enUS changed
	--grow_warning = "Grow (%d) in ~5sec",
	--grow_bar = "Grow (%d)",

	grasp_trigger1 = "von Erde ersch\195\188ttern betroffen",
	grasp_trigger2 = "von Griff des Gronnlords betroffen",
	grasp_message1 = "Griff kommt!",
	grasp_message2 = "Griff des Gronnlords!",
	grasp_warning = "Griff bald!",

	cavein_trigger = "Ihr seid von H\195\182hleneinst\195\188rz betroffen.",
	cavein_message = "H\195\182hleneinst\195\188rz auf dich!",
} end)

----------------------------------
--    Module Declaration   --
----------------------------------

BigWigsGruul = BigWigs:NewModule(boss)
BigWigsGruul.zonename = AceLibrary("Babble-Zone-2.2")["Gruul's Lair"]
BigWigsGruul.otherMenu = "Outland"
BigWigsGruul.enabletrigger = boss
BigWigsGruul.toggleoptions = {"engage", "grasp", "grow", -1, "cavein", "bosskill"}
BigWigsGruul.revision = tonumber(("$Revision: 28243 $"):sub(12, -3))

------------------------------
--      Initialization      --
------------------------------

function BigWigsGruul:OnEnable()
	slam = nil
	grasp = nil
	growcount = 1

	self:RegisterEvent("BigWigs_Message")

	self:RegisterEvent("CHAT_MSG_MONSTER_SAY")
	self:RegisterEvent("CHAT_MSG_MONSTER_EMOTE")
	self:RegisterEvent("CHAT_MSG_SPELL_PERIODIC_SELF_DAMAGE")

	self:RegisterEvent("PLAYER_REGEN_ENABLED", "CheckForWipe")
	self:RegisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH", "GenericBossDeath")
end

------------------------------
--    Event Handlers     --
------------------------------

function BigWigsGruul:CHAT_MSG_MONSTER_SAY(msg)
	if self.db.profile.engage and msg == L["engage_trigger"] then
		self:Message(L["engage_message"], "Attention")
	end
end

function BigWigsGruul:CHAT_MSG_MONSTER_EMOTE(msg)
	if self.db.profile.grow and msg == L["grow_trigger"] then
		self:Message(L["grow_message"]:format(growcount), "Important")
		growcount = growcount + 1
		self:Bar(L["grow_bar"]:format(growcount), 30, "Spell_Shadow_Charm")
		self:DelayedMessage(25, L["grow_warning"]:format(growcount), "Attention")
	end
end

function BigWigsGruul:CHAT_MSG_SPELL_PERIODIC_SELF_DAMAGE(msg)
	if not slam and self.db.profile.grasp and msg:find(L["grasp_trigger1"]) then
		self:Message(L["grasp_message1"], "Attention")
		self:DelayedMessage(83, L["grasp_warning"], "Urgent")
		self:Bar(L["grasp_warning"], 85, "Ability_ThunderClap")
		slam = true
	elseif not grasp and self.db.profile.grasp and msg:find(L["grasp_trigger2"]) then
		self:Message(L["grasp_message2"], "Urgent")
		grasp = true
	elseif self.db.profile.cavein and msg == L["cavein_trigger"] then
		self:Message(L["cavein_message"], "Personal", true, "Alarm")
	end
end

function BigWigsGruul:BigWigs_Message(text)
	if text == L["grasp_warning"] then
		slam = nil
		grasp = nil
	end
end
